@@ -9,6 +9,6 @@ if [ -f ./test.db ]; then
 fi
 bash ./scripts/lint.sh
 # Check README.md is up to date
-diff --brief docs/index.md README.md
-export PYTHONPATH=./docs/src
-pytest --cov=fastapi --cov=tests --cov=docs/src --cov-report=term-missing ${@}
+diff --brief docs/en/docs/index.md README.md
+export PYTHONPATH=./docs_src
+pytest --cov=fastapi --cov=tests --cov=docs/src --cov-report=term-missing tests ${@}
