@@ -1,7 +1,7 @@
 from fastapi import FastAPI
+from fastapi.responses import JSONResponse
+from fastapi.testclient import TestClient
 from pydantic import BaseModel
-from starlette.responses import JSONResponse
-from starlette.testclient import TestClient
 
 app = FastAPI()
 
